const config = require('./config');
const { Site1Crawler } = require('./crawlers/site1Crawler');
const { Logger } = require('./utils/logger');

const logger = new Logger('Main');

async function run() {
  try {
    logger.info('启动多网站爬虫');
    
    // 初始化各网站爬虫
    const crawlers = config.sites.map(siteConfig => {
      switch (siteConfig.name) {
        case '资讯-中国经济循环协会':
          return new Site1Crawler(siteConfig);
        // 添加更多网站...
        default:
          throw new Error(`未知网站配置: ${siteConfig.name}`);
      }
    });
    
    // 并发运行爬虫
    await Promise.all(crawlers.map(crawler => crawler.crawl()));
    
    logger.info('所有网站爬取完成');
  } catch (error) {
    logger.error('爬虫运行出错', error);
    process.exit(1);
  }
}

run();