const {isValidDateTime,randomDelay} = require('../utils')
const cheerio = require('cheerio');
const { BaseCrawler } = require('./baseCrawler');
const storageService = require('../services/storageService');

class Site1Crawler extends BaseCrawler  {
  constructor(config) {
    super(config);
  }

  async crawl() {
    this.logger.info('开始爬取');
    
    // 1. 获取分类
    const categories = await this.crawlCategories();
    this.logger.info(`发现 ${categories.length} 个分类`);
    
    // 2.爬取每个分类的分页条数
    await categories.map(async (category,index) => {
      if (index > 0) {
        category.totalPage = await this.crawlTotalPage(category)
      }
    })
    // 避免请求过于频繁
      await randomDelay();
    // 3. 爬取每个分类的新闻
    for (const category of categories) {
      await this.crawlNewsList(category);
      // 避免请求过于频繁
      await randomDelay();
    }
    
    this.logger.info('爬取完成');
  }
  // 分类
  async crawlCategories() {
    const url = this.config.baseUrl + this.config.categories.firstUrl
    const html = await this.fetchHtml(url);
    const $ = cheerio.load(html);
    
    const totalPage = Number($('.fany .a1').text().split('/')[1] || 1)
    let result = []
    await $(this.config.categories.selector).map((i, el) => {
      const name = $(el).text().trim();
      const href = $(el).attr(this.config.categories.extract.url)
      
      // 加个判断，只留分类
      if(!href.includes(this.config.categories.aUrl)) return
      result.push({
        name,
        url: href,
        totalPage: 1
      })
    }).get();
    result[0].totalPage = totalPage

    return result
  }
  
  // 分类分页数
  async crawlTotalPage(category) {
    const html = await this.fetchHtml(this.config.baseUrl + category.url);
    const $ = cheerio.load(html);
    const totalPage = Number($('.fany .a1').text().split('/')[1] || 1)
    return totalPage
  }
  // 获取新闻列表
  async crawlNewsList(category) {
    this.logger.info(`开始爬取分类新闻列表: ${category.name}/${category.totalPage}`);
    
    let page = 1;
    
    while (page <= category.totalPage) {
      const pageUrl = page === 1 ? this.config.baseUrl + category.url : `${this.config.baseUrl}${category.url}&page=${page}`;
      console.log('pageUrl:',pageUrl);
      
      if (this.isCrawled(pageUrl)) {
        page++;
        continue;
      }
     
      try {
        // 新闻列表
        const newsItems = []
        const html = await this.fetchHtml(pageUrl);
        this.markAsCrawled(pageUrl);
        const $ = cheerio.load(html);
        for (const el of $(this.config.newsList.selector)) {
          const detailUrl = $(el).find('a').attr('href')
          console.log('detailUrl',detailUrl)
          const detailHtml = await this.fetchHtml(this.config.baseUrl + detailUrl);
          const d$ = cheerio.load(detailHtml);
          let source = ''
          let times = ''
          await d$('.newstitle i').map(async(j,dEl) => {
              const t = $(dEl).text()
              if (t.includes('来源')) {
                source = t.split('：')[1].trim() 
              } else if (isValidDateTime(t)) {
                times = t
              }
          })

          newsItems.push({
            category: category.name,
            title: d$('.newstitle h1').text(),
            brief: $(el).find('p').text(),
            details: {
              source: source,
              times: times,
              content: d$('.txtedit').toString()
            }
          })
          await randomDelay();
        }
        await this.saveNews(newsItems)

        await new Promise(resolve => setTimeout(resolve, this.config.minRequestInterval || 1000));
        page++;
        
      } catch (error) {
        this.logger.error(`  第 ${page} 页爬取失败`, error);
        this.markAsFailCrawl(pageUrl)
        continue;
      }
    }
  }
  // 爬取详情
  async crawledDetails(pageUrl) {
    
  }

  async saveNews(newsItems) {
    // 实际项目中这里调用存储服务
    await storageService.batchSave(newsItems);
    console.log('保存新闻:', newsItems.length);
  }
}

module.exports = { Site1Crawler };