const axios = require('axios');
const { Logger } = require('./logger');

class HttpClient {
  constructor(config) {
    this.instance = axios.create({
      timeout: config.timeout,
      headers: config.headers
    });
    this.retryTimes = config.retryTimes || 3;
    this.logger = new Logger('HTTP');
  }

  async get(url, options = {}) {
    let lastError;
    
    for (let i = 0; i < this.retryTimes; i++) {
      try {
        const response = await this.instance.get(url, {
          responseType: 'text',
          ...options
        });
        
        if (response.status === 200) {
          return response.data;
        }
        
        throw new Error(`HTTP ${response.status}`);
      } catch (error) {
        lastError = error;
        const waitTime = 1000 * (i + 1);
        this.logger.warn(`请求失败 (${i + 1}/${this.retryTimes}), ${waitTime}ms后重试: ${url}`);
        await new Promise(resolve => setTimeout(resolve, waitTime));
      }
    }
    
    throw lastError;
  }
}

module.exports = { HttpClient };